get_qx: Get all templates imported on the server

Description Usage Arguments Value Examples

View source: R/get_qx.R

Description

get_qx returns a data frame with all the questionnaires that are currently imported on the server

Usage

1
get_qx(server = NULL, user = NULL, password = NULL)

Arguments

server

Prefix for the survey server. It is whatever comes before mysurvey.solutions: [prefix].mysurvey.solutions.

user

Username for the API user on the server.

password

Password for the API user on the server.

Value

A data frame with information about the imported questionnaires on the server.

Examples

1
2
3
4
## Not run: 
get_qx(server = "lfs2018", user = "APIuser2018", password = "SafePassword123")

## End(Not run)

l2nguyen/susoapir documentation built on Jan. 14, 2020, 2:29 p.m.