Description Usage Arguments Value Examples
get_qx returns a data frame with all the questionnaires that are currently
imported on the server
1 |
server |
Prefix for the survey server. It is whatever comes before mysurvey.solutions: [prefix].mysurvey.solutions. |
user |
Username for the API user on the server. |
password |
Password for the API user on the server. |
A data frame with information about the imported questionnaires on the server.
1 2 3 4 | ## Not run:
get_qx(server = "lfs2018", user = "APIuser2018", password = "SafePassword123")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.